@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::StaticInstall; # git description: v0.001-4-gcfa05ee
+package Dist::Zilla::Plugin::StaticInstall; # git description: v0.002-3-g28c7123
 # ABSTRACT: Identify a distribution as eligible for static installation
 # KEYWORDS: distribution metadata toolchain static dynamic installation
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -37,7 +37,7 @@ around dump_config => sub
 
     $config->{+__PACKAGE__} = {
         mode => $self->mode,
-        dry_run => $self->dry_run,
+        dry_run => $self->dry_run ? 1 : 0,
     };
 
     return $config;
@@ -57,10 +57,8 @@ sub metadata
     return +{ x_static_install => 0 } if $mode eq 'off';
     return +{ x_static_install => 1 } if $mode eq 'on';
 
-    return +{} if $self->dry_run;
-
-    # we'll calculate this value later in the build and munge it in
-    return +{ x_static_install => 'PLACEHOLDER' };
+    # if mode = auto and dry_run = 0, we'll add it later
+    return +{};
 }
 
 sub setup_installer
@@ -176,7 +174,7 @@ Dist::Zilla::Plugin::StaticInstall - Identify a distribution as eligible for sta
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
